==> release.12.0.73.1.tgz: prontus/cpan/js-local/prontus_edit/customTool_copy.js <==
(function() {
    let FileExplorerTool_CopyCustom = function(fe) {
        if (!(this instanceof FileExplorerTool_CopyCustom))  return new FileExplorerTool_CopyCustom(fe);

        let enabled = false;
        let node = fe.AddToolbarButton('fe_fileexplorer_folder_tool_copy', fe.Translate('Copy'));
        let configModalConfirm = {
            title: "Copiar Archivo",
            content: '' +
                '<form action="" class="formName1">' +
                '<div class="form-group">' +
                '<label>Ingresa Nombre del Archivo </label>' +
                '<input type="text" id="nombre_archivo_copiar" placeholder="Nombre del archivo de destino" class="name form-control" required>' +
                '</div>' +
                '</form>',
            icon: "glyphicon glyphicon-question-sign",
            columnClass: 'col-md-offset-6 col-md-12',
            containerFluid: true,
            onContentReady: function () {
                let currentSelectedEntrie = fe.GetSelectedFolderEntries();
                let currentFolderEntries = fe.GetCurrentFolder().GetEntries();
                let currentFileName = currentSelectedEntrie[0].name;
                let name = currentFileName.split('.').slice(0, -1).join('.');
                let newName = name + "_copia." + currentSelectedEntrie[0].ext;

                $("#nombre_archivo_copiar").val(newName);

                // bind to events
                var jc = this;
                this.$content.find('form').on('submit', function (e) {
                    // if the user submits the form by pressing enter in the field.
                    e.preventDefault();
                    jc.$$ok.trigger('click'); // reference the button and click it
                });
            },
            buttons: {
                ok: {
                    keys: ['enter'],
                    text: "Copiar",
                    btnClass: 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgreen nextgreen',
                    action: function () {
                        var nombre_archivo_copiar = $('#nombre_archivo_copiar').val();
                        if (!nombre_archivo_copiar) {
                            $.alert({
                                type: 'red',
                                icon: "glyphicon glyphicon-remove-circle",
                                title: "Error",
                                content: 'Ingresa un nombre válido',
                                columnClass: 'medium'
                            });
                            return false;
                        } else {
                            CopyHandler(fe, nombre_archivo_copiar);
                        }
                    }

                },
                cancel: {
                    text: "Cancelar",
                    action: function () {}
                }
            }
        };
        let CopyHandler = function (fe, nomFile) {
            let paths = fe.GetCurrentFolder().GetPath();
            let path = "";
            let entries = fe.GetSelectedFolderEntries();

            paths.forEach(function (item) {
                path += item[0] + "/";
            });

            let pathWithoutEndSlash = path.substring(0, path.length - 1);
            let theFile = entries[0].name;
            let xhr = new fe.PrepareXHR({
                url: '/cgi-cpn/prontus_edit_copy.cgi',
                params: {
                    _prontus_id: $("body").data("prontus-id"),
                    _path_file: path + theFile,
                    _curr_dir: pathWithoutEndSlash,
                    nom_new_file: nomFile,
                    sbm_accion: "Nuevo"
                },
                onsuccess: function(e) {
                    let data = JSON.parse(e.target.response);

                    if (data.status == 1) {
                        fe.RefreshFolders(true);
                    } else {
                        showModalAlert({
                            title: "Error al copiar",
                            type: "red",
                            msg: data.msg
                        });
                    }

                },
                onerror: function(e) {
                    showModalAlert({
                        title: "Error al copiar",
                        type: "red",
                        msg: "Ocurrió un error al tratar de copiar el archivo."
                    });
                }
            });

            xhr.Send();
        };

        // Handle clicks.
        let ClickHandler = function(e) {
            if (enabled) {
                showModalConfirm(configModalConfirm);
            }
        };

        node.addEventListener('click', ClickHandler);

        let UpdateToolHandler = function(currfolder, attrs) {
            let prevenabled = enabled;

            enabled = (!currfolder.waiting && fe.GetNumSelectedItems());

            if (fe.GetNumSelectedItems() > 1) enabled = false;

            if (enabled) {
                let selectedFolderEntries = fe.GetSelectedFolderEntries();

                if (selectedFolderEntries[0].type == "folder") enabled = false;
            }

            if (prevenabled !== enabled) {
                if (enabled) {
                    node.classList.remove('fe_fileexplorer_disabled');
                } else {
                    node.classList.add('fe_fileexplorer_disabled');
                }

                fe.ToolStateUpdated();
            }
        };

        fe.addEventListener('update_tool', UpdateToolHandler);

        let DestroyToolHandler = function() {
            node.removeEventListener('click', ClickHandler);
        };

        fe.addEventListener('destroy', DestroyToolHandler);
    };

    window.FileExplorer.RegisterTool(1, FileExplorerTool_CopyCustom);
})();

==> release.12.3.1.2.tgz: prontus/cpan/js-local/prontus_edit/customTool_copy.js <==
(function() {
    let FileExplorerTool_CopyCustom = function(fe) {
        if (!(this instanceof FileExplorerTool_CopyCustom))  return new FileExplorerTool_CopyCustom(fe);

        let enabled = false;
        let node = fe.AddToolbarButton('fe_fileexplorer_folder_tool_copy', fe.Translate('Copy'));
        let configModalConfirm = {
            title: ProntusL10n.get('prontus_edit_copy_label'),
            content: '' +
                '<form action="" class="formName1">' +
                '<div class="form-group">' +
                '<label>'+ProntusL10n.get('prontus_edit_filename_label')+' </label>' +
                '<input type="text" id="nombre_archivo_copiar" placeholder="'+ProntusL10n.get('prontus_edit_end_filename_ph')+'" class="name form-control" required>' +
                '</div>' +
                '</form>',
            icon: "glyphicon glyphicon-question-sign",
            columnClass: 'col-md-offset-6 col-md-12',
            containerFluid: true,
            onContentReady: function () {
                let currentSelectedEntrie = fe.GetSelectedFolderEntries();
                let currentFolderEntries = fe.GetCurrentFolder().GetEntries();
                let currentFileName = currentSelectedEntrie[0].name;
                let name = currentFileName.split('.').slice(0, -1).join('.');
                let newName = name + "_copia." + currentSelectedEntrie[0].ext;

                $("#nombre_archivo_copiar").val(newName);

                // bind to events
                var jc = this;
                this.$content.find('form').on('submit', function (e) {
                    // if the user submits the form by pressing enter in the field.
                    e.preventDefault();
                    jc.$$ok.trigger('click'); // reference the button and click it
                });
            },
            buttons: {
                ok: {
                    keys: ['enter'],
                    text: ProntusL10n.get('prontus_edit_copy_label'),
                    btnClass: 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgreen nextgreen',
                    action: function () {
                        var nombre_archivo_copiar = $('#nombre_archivo_copiar').val();
                        if (!nombre_archivo_copiar) {
                            $.alert({
                                type: 'red',
                                icon: "glyphicon glyphicon-remove-circle",
                                title: ProntusL10n.get('global_error_title'),
                                content: ProntusL10n.get('prontus_edit_invalid_name_warning'),
                                columnClass: 'medium'
                            });
                            return false;
                        } else {
                            CopyHandler(fe, nombre_archivo_copiar);
                        }
                    }

                },
                cancel: {
                    text: ProntusL10n.get('global_cancel_label'),
                    action: function () {}
                }
            }
        };
        let CopyHandler = function (fe, nomFile) {
            let paths = fe.GetCurrentFolder().GetPath();
            let path = "";
            let entries = fe.GetSelectedFolderEntries();

            paths.forEach(function (item) {
                path += item[0] + "/";
            });

            let pathWithoutEndSlash = path.substring(0, path.length - 1);
            let theFile = entries[0].name;
            let xhr = new fe.PrepareXHR({
                url: '/cgi-cpn/prontus_edit_copy.cgi',
                params: {
                    _prontus_id: $("body").data("prontus-id"),
                    _path_file: path + theFile,
                    _curr_dir: pathWithoutEndSlash,
                    nom_new_file: nomFile,
                    action: 'new'
                },
                onsuccess: function(e) {
                    let data = JSON.parse(e.target.response);

                    if (data.status == 1) {
                        fe.RefreshFolders(true);
                    } else {
                        showModalAlert({
                            title: ProntusL10n.get('prontus_edit_copy_error'),
                            type: "red",
                            msg: data.msg
                        });
                    }

                },
                onerror: function(e) {
                    showModalAlert({
                        title: ProntusL10n.get('prontus_edit_copy_error'),
                        type: "red",
                        msg: ProntusL10n.get('prontus_edit_copy_error_long')
                    });
                }
            });

            xhr.Send();
        };

        // Handle clicks.
        let ClickHandler = function(e) {
            if (enabled) {
                showModalConfirm(configModalConfirm);
            }
        };

        node.addEventListener('click', ClickHandler);

        let UpdateToolHandler = function(currfolder, attrs) {
            let prevenabled = enabled;

            enabled = (!currfolder.waiting && fe.GetNumSelectedItems());

            if (fe.GetNumSelectedItems() > 1) enabled = false;

            if (enabled) {
                let selectedFolderEntries = fe.GetSelectedFolderEntries();

                if (selectedFolderEntries[0].type == "folder") enabled = false;
            }

            if (prevenabled !== enabled) {
                if (enabled) {
                    node.classList.remove('fe_fileexplorer_disabled');
                } else {
                    node.classList.add('fe_fileexplorer_disabled');
                }

                fe.ToolStateUpdated();
            }
        };

        fe.addEventListener('update_tool', UpdateToolHandler);

        let DestroyToolHandler = function() {
            node.removeEventListener('click', ClickHandler);
        };

        fe.addEventListener('destroy', DestroyToolHandler);
    };

    window.FileExplorer.RegisterTool(1, FileExplorerTool_CopyCustom);
})();
